<template>
  <a-card
    :bordered="false"
    :class="'cust-erp-sub-tab'"
  >
    <a-table
      ref="table"
      bordered
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      @change="handleTableChange"
      :scroll='{x:2000}'
    >
      <template
        v-for="col in columns"
        :slot="col.dataIndex"
        slot-scope='text, record, index'
      >
        <div :key="col.dataIndex">
          <a-input
            :value="text"
            v-if="col.dataIndex == 'location'"
            :maxLength="32"
            auto-size
            placeholder="请输入部位"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <j-image-upload
            :value="text"
            v-if="col.dataIndex == 'sketchMap'"
            :isMultiple="false"
            auto-size
            placeholder="请上传图片"
            @change="(e)=>handleChange(e, record.key, col, index)"
          >
          </j-image-upload>
          <a-input
            :value="text"
            v-if="col.dataIndex == 'maintenanceItem'"
            :maxLength="32"
            auto-size
            placeholder="请输入维修项目"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input
            :value="text"
            v-if="col.dataIndex == 'maintenanceRequire'"
            :maxLength="32"
            auto-size
            placeholder="请输入维修要求"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input
            :value="text"
            v-if="col.dataIndex == 'maintenanceWay'"
            :maxLength="32"
            auto-size
            placeholder="请输入方法"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input
            :value="text"
            v-if="col.dataIndex == 'maintenanceTooling'"
            :maxLength="32"
            auto-size
            placeholder="请输入工具"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input
            :value="text"
            v-if="col.dataIndex == 'safetyRequirement'"
            :maxLength="32"
            auto-size
            placeholder="请输入安全要求"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input-number
            :value="text"
            v-if="col.dataIndex == 'repairCycle'"
            placeholder="请输入维修周期"
            :min="0"
            :max="99999"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <a-input-number
            :value="text"
            v-if="col.dataIndex == 'timeQuota'"
            placeholder="请输入工时定额"
            :min="0"
            :max="99999"
            @change="(e)=>handleChange(e, record.key, col, index)"
          />
          <j-dict-select-tag
            allow-clear
            :value="text"
            v-if="col.dataIndex == 'mamaintenanceSpecialtyId'"
            placeholder="请选择维保专业"
            dictCode="mom_eam_maintenance_specialty,name,id,del_flag!='1'"
            @change="(e)=>handleChange(e, record.key, col, index)"
            style="width: 150px;"
          />
        </div>
      </template>
      <span
        slot='action'
        slot-scope='text, record,index'
      >
        <a @click="handleDeleteFake(index)">删除</a>
      </span>
    </a-table>
    <a-button
      style="width: 100%; margin-top: 16px; margin-bottom: 8px"
      type="dashed"
      icon="plus"
      @click="addMaterial"
    >添加维修内容
    </a-button>
    <div :style="{width: '100%',border: '1px solid #e9e9e9',padding: '10px 16px',background: '#fff',}">
      <a-row :style="{textAlign:'right'}">
        <a-button
          :style="{marginRight: '8px'}"
          @click="handleCancel"
        >
          清空
        </a-button>
        <!-- <a-button
           @click="handleOk(1)"
           type="primary"
           :style="{marginRight: '8px'}"
         >暂存</a-button>
         <a-button
         @click="handleOk(0)"
         type="primary"
         >保存</a-button> -->
      </a-row>
      <!-- :disabled="false" -->
    </div>
  </a-card>
</template>
<script>
import { postAction, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import pick from 'lodash.pick'
import JEllipsis from '@/components/jeecg/JEllipsis'
export default {
  name: 'RepairOrderDetailReportModel',
  mixins: [JeecgListMixin],
  components: {
    JEllipsis,
  },
  props: {
    repairOrderId: {
      type: String,
      required: false,
      default: ''
    },
    repairOrderStatus: {
      type: String,
      required: false,
      default: ''
    }
  },
  data() {
    return {
      title: "维修内容",
      // flag: false,//主页面的标记位  用于区分是否确认过工单工艺 来区分table页展示 工单工序 还是产品工序
      visible: false,
      // model: {},
      // obj: {},
      // maskClosable: true,
      // confirmLoading: false,
      form: this.$form.createForm(this),
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 99,
        pageSizeOptions: ['99', '199'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      validatorRules: {
        faultCause: {
          rules: [
            { required: true, message: '请填写故障原因!' },
          ]
        },
        faultType: {
          rules: [
            { required: false, message: '请填写故障类型!' },
          ]
        },
      },
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      // drawerWidth: "100%",
      // visible: false,
      disableSubmit: false,
      // disableSelect: false,
      // loading: false,
      dataSource: [],
      columns: [
        {
          title: '*部位',
          align: "center",
          scopedSlots: { customRender: 'location' },
          dataIndex: 'location',
          className: 'red',
          width: 200,

        },
        {
          title: '*示意图',
          align: "center",
          scopedSlots: { customRender: 'sketchMap' },
          dataIndex: 'sketchMap',
          className: 'red',
          width: 200
        },
        {
          title: '*维修项目',
          align: "center",
          scopedSlots: { customRender: 'maintenanceItem' },
          dataIndex: 'maintenanceItem',
          className: 'red',
          width: 200
        },
        {
          title: '*维修要求',
          align: "center",
          scopedSlots: { customRender: 'maintenanceRequire' },
          dataIndex: 'maintenanceRequire',
          className: 'red',
          width: 200
        },
        {
          title: '*方法',
          align: "center",
          scopedSlots: { customRender: 'maintenanceWay' },
          dataIndex: 'maintenanceWay',
          className: 'red',
          width: 200
        },
        {
          title: '*工具',
          align: "center",
          scopedSlots: { customRender: 'maintenanceTooling' },
          dataIndex: 'maintenanceTooling',
          className: 'red',
          width: 200
        },
        {
          title: '*安全要求',
          align: "center",
          scopedSlots: { customRender: 'safetyRequirement' },
          dataIndex: 'safetyRequirement',
          className: 'red',
          width: 200
        },
        {
          title: '*维修周期',
          align: "center",
          scopedSlots: { customRender: 'repairCycle' },
          dataIndex: 'repairCycle',
          className: 'red',
          width: 200
        },
        {
          title: '*工时定额',
          align: "center",
          scopedSlots: { customRender: 'timeQuota' },
          dataIndex: 'timeQuota',
          className: 'red',
          width: 200
        },
        {
          title: '*维保专业',
          align: "center",
          scopedSlots: { customRender: 'mamaintenanceSpecialtyId' },
          dataIndex: 'mamaintenanceSpecialtyId',
          className: 'red',
          width: 200
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          width: 100,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/eam/repairOrder/listRepairOrderDetailByMainId",
      },
      // changeIndex: 0
    }
  },
  created() {
    this.queryParam['repairOrderId'] = this.repairOrderId;
    this.loadData(1);
  },
  methods: {
    addMaterial() {
      this.dataSource.push({ location: '', sketchMap: '', maintenanceItem: '', maintenanceRequire: '', maintenanceWay: '', maintenanceTooling: '', safetyRequirement: '', timeQuota: 0, repairCycle: 0, id: this.getUuiD(16), repairOrderId: this.repairOrderId })
    },
    handleCancel() {
      this.close()
    },
    close() {
      this.$emit('close');
      this.dataSource = [];
      this.disableSubmit = false;
      this.visible = false;
    },
    handleDeleteFake(index) {
      this.dataSource.pop(index);
    },
    handleChange(value, key, column, index) {
      let that = this;
      const temp = [...that.dataSource];
      const target = temp[index];
      if (target) {
        target[column.dataIndex] = value;
        if ('location' == column.dataIndex) {
          target['location'] = value.target.value;
        }
        if ('sketchMap' == column.dataIndex) {
          target['sketchMap'] = value;
        }
        if ('maintenanceItem' == column.dataIndex) {
          target['maintenanceItem'] = value.target.value;
        }
        if ('maintenanceRequire' == column.dataIndex) {
          target['maintenanceRequire'] = value.target.value;
        }
        if ('maintenanceWay' == column.dataIndex) {
          target['maintenanceWay'] = value.target.value;
        }
        if ('maintenanceTooling' == column.dataIndex) {
          target['maintenanceTooling'] = value.target.value;
        }
        if ('safetyRequirement' == column.dataIndex) {
          target['safetyRequirement'] = value.target.value;
        }
        if ('timeQuota' == column.dataIndex) {
          target['timeQuota'] = value;
        }
        if ('repairCycle' == column.dataIndex) {
          target['repairCycle'] = value;
        }
        that.dataSource = temp;
      }
    },
    clearList() {
      this.dataSource = [];
      this.ipagination.current = 1
    },
    getUuiD(randomLength) {
      return Number(
        Math.random()
          .toString()
          .substr(2, randomLength) + Date.now()
      ).toString(36)
    },
  },
  watch: {
    dataSource: {
      deep: true,
      immediate: true,
      handler(val) {
        this.$emit('getDetailList', val);
      }
    },
    repairOrderId: {
      immediate: true,
      handler(val) {
        this.clearList();
        this.queryParam['repairOrderId'] = val
        this.loadData(1);
      }
    }
  }
}
</script>

<style scoped>
/deep/ .red {
  color: red;
}
</style>